@@ -1,5 +1,5 @@
 #
-# $Id: IPv4.pm 360 2015-01-20 18:36:06Z gomor $
+# $Id: IPv4.pm 367 2015-02-15 17:11:07Z gomor $
 #
 package Net::Frame::Layer::IPv4;
 use strict;
@@ -103,6 +103,8 @@ BEGIN {
    my $osname = {
       freebsd => [ \&_fixLenBsd, ],
       netbsd  => [ \&_fixLenBsd, ],
+      openbsd => [ \&_fixLenBsd, ],
+      darwin  => [ \&_fixLenBsd, ],
    };
 
    *_fixLen = $osname->{$^O}->[0] || \&_fixLenOther;
